==> haskell-network-multicast-0.3.2-212-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-714eqIcI8XaInOD4m8xFFa
key:                  network-multicast-0.3.2-714eqIcI8XaInOD4m8xFFa
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  7e52da0d7f022e34adfa0d6b587cdc2b
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.2.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-714eqIcI8XaInOD4m8xFFa
depends:
    base-4.16.4.0 network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-bsd-2.8.1.0-8odhSoml6qLDJTfWl3Ma9Z

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-214-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-D28PYHPjV4J4UlVIUFXqON
key:                  network-multicast-0.3.2-D28PYHPjV4J4UlVIUFXqON
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  d08e285968f95ac7ccd5ca47ab6807dc
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.2.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-D28PYHPjV4J4UlVIUFXqON
depends:
    base-4.16.4.0 network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-bsd-2.8.1.0-1Y5x0mszWxhBcPjCNBOVSm

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
